from __future__ import unicode_literals
from django.db import models
from django.contrib import admin
from django.core.urlresolvers import reverse
# Create your models here.
class Encuesta(models.Model):
     id_encuesta=models.AutoField(primary_key=True, editable=False)
     titulo=models.CharField(max_length=50)
     cant_participante = models.IntegerField(null=False, blank=True)
     fecha_creacion=models.DateField(auto_now_add=False)
     estado=models.BooleanField(default=False)
     contPart = models.IntegerField(default=0)

     class Meta:
         ordering = ["id_encuesta"]
         verbose_name_plural = "Encuesta"

     def __str__(self):
             return '%s' % (self.titulo)

class Usuario(models.Model):
    id_usuario=models.AutoField(primary_key=True, max_length=10)
    id_encuesta=models.OneToOneField(Encuesta)
    ip_usuario=models.GenericIPAddressField(protocol='IPv4', blank=True, null=True, unique=False, default=None)

    class Meta:
        ordering = ["id_usuario"]
        verbose_name_plural = "Usuarios"

        def __str__(self):  # __unicode__ en Python 2
          return '%s' % (self.id_usuario)

class Pregunta(models.Model):
    id_pregunta=models.AutoField(primary_key=True)
    id_encuesta=models.ForeignKey(Encuesta)
    descripcion=models.CharField(max_length=100)

    class Meta:
        ordering = ["id_pregunta"]
        verbose_name_plural = "Preguntas"

    def get_absolute_url(self):
        return reverse('pregunta_detail',kwargs={'pk':self.id_pregunta})

    def __str__(self):
        return '%s' % (self.descripcion)

class Respuesta(models.Model):
    id_respuesta=models.AutoField(primary_key=True)
    id_pregunta=models.ForeignKey(Pregunta)
    contenido=models.CharField(max_length=100)
    votes = models.IntegerField(default=0)
    mejor_respuesta=models.BooleanField("Respuesta Favorita", default=False)

    class Meta:
        ordering= ["id_respuesta"]
        verbose_name_plural="Respuestas"

    def __str__(self):
        return '%s' % (self.contenido)
